striplog
========

.. image:: https://img.shields.io/travis/agile-geoscience/striplog.svg
    :target: https://travis-ci.org/agile-geoscience/striplog
    :alt: Travis build status
    
.. image:: https://img.shields.io/pypi/status/striplog.svg
    :target: https://pypi.python.org/pypi/striplog/
    :alt: Development status

.. image:: https://img.shields.io/pypi/v/striplog.svg
    :target: https://pypi.python.org/pypi/striplog/
    :alt: Latest version
    
.. image:: https://img.shields.io/pypi/pyversions/striplog.svg
    :target: https://pypi.python.org/pypi/striplog/
    :alt: Python version
    
.. image:: https://coveralls.io/repos/agile-geoscience/striplog/badge.svg?branch=master&service=github
    :target: https://coveralls.io/github/agile-geoscience/striplog?branch=master
    :alt: Coveralls

.. image:: https://img.shields.io/codacy/ad9af103cba14d33abd5b327727ff644.svg 
    :target: https://www.codacy.com/app/matt/striplog/dashboard
    :alt: Codacy code review

.. image:: https://img.shields.io/pypi/l/striplog.svg
    :target: http://www.apache.org/licenses/LICENSE-2.0
    :alt: License

Lithology and stratigraphic logs for wells. 

* `A blog post about striplog <http://www.agilegeoscience.com/blog/2015/4/15/striplog>`_
* `Another one, with a video <http://www.agilegeoscience.com/blog/2015/7/10/geophysics-at-scipy-2015>`_


Docs
----

* `Read The Docs <https://striplog.readthedocs.org/>`_


Dependencies
------------

* `NumPy <http://www.numpy.org/>`_
* `matplotlib <http://matplotlib.org/>`_


Install
-------

* ``pip install striplog``

SciPy 2015
----------

`Here's a presentation about Striplog. <https://docs.google.com/presentation/d/16HJsJJQylb2_8D2NS1p2cjp1yzslqUl_51BN16J5Y2k/edit?usp=sharing>`_
